@@ -1,5 +1,3 @@
-#' @docType package
-#'
 #' @name icesSD-package
 #'
 #' @aliases icesSD
@@ -12,14 +10,17 @@
 #' @details
 #' \emph{Get dataset:}
 #' \tabular{ll}{
-#'   \code{\link{getSD}}    \tab full stock list\cr
+#'   \code{\link{getSD}}    \tab full stock list, with filtering by stock and year\cr
+#' }
+#' \emph{Show on screen:}
+#' \tabular{ll}{
+#'   \code{\link{showStock}} \tab one stock, in a readable format
 #' }
 #'
 #' @author Colin Millar, Scott Large, and Arni Magnusson.
 #'
 #' @references
-#' ICES Stock Database: \url{http://sd.ices.dk}.
+#' ICES Stock Database: \url{https://sd.ices.dk}.
 #'
-#' ICES Stock Database web services: \url{http://sd.ices.dk/services/}.
-
-NA
+#' ICES Stock Database web services: \url{https://sd.ices.dk/services/}.
+"_PACKAGE"
